"""
data是classicML中关于数据操作的模块,
它可以实现数据的自动加载和预处理等功能,
并开放大量的预处理函数的接口.
"""
from classicML.backend.python.data import preprocessing
from classicML.backend.python.data.dataset import Dataset

__version__ = 'backend.python.data.0.2'



"""An easy-to-use ML framework."""
__version__ = '0.7b0'

import os
import logging

# 配置默认环境变量
os.environ.setdefault('CLASSICML_ENGINE', 'Python')
os.environ.setdefault('CLASSICML_FONT', 'Arial Unicode MS')
os.environ.setdefault('CLASSICML_PRECISION', '32-bit')
# 系统logger
logging.basicConfig(level=logging.INFO)
CLASSICML_LOGGER = logging.getLogger(name='classicML')
CLASSICML_LOGGER.info('正在使用 {} 引擎'.format(os.environ['CLASSICML_ENGINE']))

from classicML.framework.dtypes import float32
from classicML.framework.dtypes import float64
from classicML.framework.dtypes import int32
from classicML.framework.dtypes import int64
from classicML.framework.dtypes import set_precision
# 全局精度.
_cml_precision = set_precision()

from classicML.api import models
from classicML.api import plots

from classicML.api import BaseModel
from classicML.api import AveragedOneDependentEstimator
from classicML.api import AODE
from classicML.api import BackPropagationNeuralNetwork
from classicML.api import BPNN
from classicML.api import DecisionTreeClassifier
from classicML.api import LinearDiscriminantAnalysis
from classicML.api import LDA
from classicML.api import LogisticRegression
from classicML.api import NaiveBayesClassifier
from classicML.api import NB
from classicML.api import RadialBasisFunctionNetwork
from classicML.api import RBF
from classicML.api import SuperParentOneDependentEstimator
from classicML.api import SPODE
from classicML.api import SupportVectorClassifier
from classicML.api import SVC

from classicML.backend import activations
from classicML.backend import callbacks
from classicML.backend import data
from classicML.backend import initializers
from classicML.backend import io
from classicML.backend import kernels
from classicML.backend import losses
from classicML.backend import metrics
from classicML.backend import optimizers
from classicML.backend import tree

from classicML import benchmarks



from glob import glob
from setuptools import setup, find_packages
from pybind11.setup_helpers import Pybind11Extension, build_ext

with open('README.md', 'r') as fp:
    long_description = fp.read()

extension_modules = [
    # backend._utils模块
    Pybind11Extension(
        'classicML/backend/cc/_utils',
        sorted(glob('classicML/backend/cc/_utils.cc')),
        language='c++',
    ),
    # backend.activations模块
    Pybind11Extension(
        'classicML/backend/cc/activations',
        sorted(glob('classicML/backend/cc/activations.cc')),
        include_dirs=[
            '/usr/local/include/eigen3',  # /path/to/eigen3/download
        ],
        language='c++',
    ),
    # backend.callbacks模块
    Pybind11Extension(
        'classicML/backend/cc/callbacks',
        sorted(glob('classicML/backend/cc/callbacks.cc')),
        language='c++',
    ),
    # backend.initializers模块
    Pybind11Extension(
        'classicML/backend/cc/initializers',
        sorted(glob('classicML/backend/cc/*.cc')),
        include_dirs=[
            '/usr/local/include/eigen3',
        ],
        language='c++',
    ),
    # backend.kernels模块
    Pybind11Extension(
        'classicML/backend/cc/kernels',
        sorted(glob('classicML/backend/cc/*.cc')),
        include_dirs=[
            '/usr/local/include/eigen3',
        ],
        language='c++',
    ),
    # backend.losses模块
    Pybind11Extension(
        'classicML/backend/cc/losses',
        sorted(glob('classicML/backend/cc/losses.cc')),
        include_dirs=[
            '/usr/local/include/eigen3',
        ],
        language='c++',
    ),
    # backend.metrics模块
    Pybind11Extension(
        'classicML/backend/cc/metrics',
        sorted(glob('classicML/backend/cc/metrics.cc')),
        include_dirs=[
            '/usr/local/include/eigen3',
        ],
        language='c++',
    ),
    # backend.ops模块
    Pybind11Extension(
        'classicML/backend/cc/ops',
        sorted(glob('classicML/backend/cc/*.cc')),
        include_dirs=[
            '/usr/local/include/eigen3',
        ],
        language='c++',
    )
]

setup(
    name='classicML',
    version='0.7b0',
    description='An easy-to-use ML framework',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Steve R. Sun',
    author_email='s1638650145@gmail.com',
    url='https://github.com/sun1638650145/classicML',
    packages=find_packages(),
    ext_modules=extension_modules,
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: C++',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
    ],
    license='Apache Software License',
    cmdclass={'build_ext': build_ext},
    install_requires=[
        'h5py>=3.2.0, <=3.2.1',
        'matplotlib>=3.4.0, <=3.4.2',
        'numpy>=1.20.0, <=1.20.3',
        'pandas>=1.2.0, <=1.2.4',
        'psutil>=5.7.2, <=5.8.0',
    ],
    python_requires='>=3.7',
)
